==> medium-editor-1.1.1.tgz: package/spec/buttons.spec.js <==
/*global MediumEditor, describe, it, expect, spyOn,
         afterEach, beforeEach, selectElementContents,
         jasmine, fireEvent*/

describe('Buttons TestCase', function () {
    'use strict';

    beforeEach(function () {
        this.body = document.getElementsByTagName('body')[0];
        this.el = document.createElement('div');
        this.el.className = 'editor';
        this.el.innerHTML = 'lorem ipsum';
        this.body.appendChild(this.el);
    });

    afterEach(function () {
        var elements = document.querySelectorAll('.medium-editor-toolbar'),
            i,
            sel = window.getSelection();
        for (i = 0; i < elements.length; i += 1) {
            this.body.removeChild(elements[i]);
        }
        this.body.removeChild(this.el);
        sel.removeAllRanges();
    });

    describe('Button Initial State', function () {
        beforeEach(function () {
            jasmine.Clock.useMock();
        });

        it('should hide buttons if they are in the excludedActions option', function () {
            var editor = new MediumEditor('.editor', {excludedActions: ['b', 'i', 'a']});
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            expect(editor.toolbar.querySelector('[data-element="b"]').style.display).toBe('none');
            expect(editor.toolbar.querySelector('[data-element="i"]').style.display).toBe('none');
            expect(editor.toolbar.querySelector('[data-element="a"]').style.display).toBe('none');
            expect(editor.toolbar.querySelector('[data-element="u"]').style.display).toBe('block');
            expect(editor.toolbar.querySelector('[data-element="h3"]').style.display).toBe('block');
            expect(editor.toolbar.querySelector('[data-element="h4"]').style.display).toBe('block');
            expect(editor.toolbar.querySelector('[data-element="q"]').style.display).toBe('block');
        });

        it('should activate button if selection already has the element', function () {
            var button,
                editor = new MediumEditor('.editor');
            this.el.innerHTML = '<b>lorem ipsum</b>';
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            expect(button.className).toContain('medium-editor-button-active');
        });
    });

    describe('Button click', function () {
        beforeEach(function () {
            jasmine.Clock.useMock();
        });

        it('should set active class on click', function () {
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            fireEvent(button, 'click');
            expect(button.className).toContain('medium-editor-button-active');
        });

        it('should check for selection when selection is undefined', function () {
            spyOn(MediumEditor.prototype, 'checkSelection');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            editor.selection = undefined;
            fireEvent(button, 'click');
            expect(editor.checkSelection).toHaveBeenCalled();
        });

        it('should remove active class if button has it', function () {
            this.el.innerHTML = '<b>lorem ipsum</b>';
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            expect(button.className).toContain('medium-editor-button-active');
            fireEvent(button, 'click');
            expect(button.className).not.toContain('medium-editor-button-active');
        });

        it('should execute the button action', function () {
            spyOn(MediumEditor.prototype, 'execAction');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            fireEvent(button, 'click');
            expect(editor.execAction).toHaveBeenCalled();
        });

        it('should call the execCommand for native actions', function () {
            spyOn(document, 'execCommand').andCallThrough();
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="i"]');
            fireEvent(button, 'click');
            expect(document.execCommand).toHaveBeenCalled();
            expect(this.el.innerHTML).toBe('<i>lorem ipsum</i>');
        });

        it('should execute the button action', function () {
            spyOn(MediumEditor.prototype, 'execAction');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            fireEvent(button, 'click');
            expect(editor.execAction).toHaveBeenCalled();
        });

        it('should call the triggerAnchorAction method when button element is "a"', function () {
            spyOn(MediumEditor.prototype, 'triggerAnchorAction');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="a"]');
            fireEvent(button, 'click');
            expect(editor.triggerAnchorAction).toHaveBeenCalled();
        });
    });

    describe('AppendEl', function () {
        beforeEach(function () {
            jasmine.Clock.useMock();
        });

        it('should call the appendEl method when button action is append', function () {
            spyOn(MediumEditor.prototype, 'appendEl');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="h3"]');
            fireEvent(button, 'click');
            expect(editor.appendEl).toHaveBeenCalled();
        });

        it('should create an h3 element when header1 is clicked', function () {
            this.el.innerHTML = '<p><b>lorem ipsum</b></p>';
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="h3"]');
            fireEvent(button, 'click');
            expect(this.el.innerHTML).toBe('<h3><b>lorem ipsum</b></h3>');
        });

        it('should get back to a p element if parent element is the same as the action', function () {
            this.el.innerHTML = '<h3><b>lorem ipsum</b></h3>';
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="h3"]');
            fireEvent(button, 'click');
            expect(this.el.innerHTML).toBe('<p><b>lorem ipsum</b></p>');
        });

        it('should transfer parent element attributes', function () {
            this.el.innerHTML = '<p class="test" data-transfer="test"><b>lorem ipsum</b></p>';
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="h3"]');
            fireEvent(button, 'click');
            expect(this.el.innerHTML).toBe('<h3 class="test" data-transfer="test"><b>lorem ipsum</b></h3>');
        });

    });

    describe('First and Last', function () {
        it('should add a special class to the first and last buttons', function () {
            var editor = new MediumEditor('.editor'),
                buttons = editor.toolbar.querySelectorAll('button');
            expect(buttons[0].className).toContain('medium-editor-button-first');
            expect(buttons[1].className).not.toContain('medium-editor-button-first');
            expect(buttons[1].className).not.toContain('medium-editor-button-last');
            expect(buttons[buttons.length - 1].className).toContain('medium-editor-button-last');
        });
    });
});

==> medium-editor-1.7.0.tgz: package/spec/buttons.spec.js <==
/*global MediumEditor, describe, it, expect, spyOn,
         afterEach, beforeEach, selectElementContents,
         jasmine, fireEvent*/

describe('Buttons TestCase', function () {
    'use strict';

    beforeEach(function () {
        this.body = document.getElementsByTagName('body')[0];
        this.el = document.createElement('div');
        this.el.className = 'editor';
        this.el.innerHTML = 'lorem ipsum';
        this.body.appendChild(this.el);
    });

    afterEach(function () {
        var elements = document.querySelectorAll('.medium-editor-toolbar'),
            i,
            sel = window.getSelection();
        for (i = 0; i < elements.length; i += 1) {
            this.body.removeChild(elements[i]);
        }
        this.body.removeChild(this.el);
        sel.removeAllRanges();
    });

    describe('Button Initial State', function () {
        beforeEach(function () {
            jasmine.Clock.useMock();
        });

        it('should activate button if selection already has the element', function () {
            var button,
                editor = new MediumEditor('.editor');
            this.el.innerHTML = '<b>lorem ipsum</b>';
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            expect(button.className).toContain('medium-editor-button-active');
        });
    });

    describe('Button click', function () {
        beforeEach(function () {
            jasmine.Clock.useMock();
        });

        it('should set active class on click', function () {
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            fireEvent(button, 'click');
            expect(button.className).toContain('medium-editor-button-active');
        });

        it('should check for selection when selection is undefined', function () {
            spyOn(MediumEditor.prototype, 'checkSelection');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            editor.selection = undefined;
            fireEvent(button, 'click');
            expect(editor.checkSelection).toHaveBeenCalled();
        });

        it('should remove active class if button has it', function () {
            this.el.innerHTML = '<b>lorem ipsum</b>';
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            expect(button.className).toContain('medium-editor-button-active');
            fireEvent(button, 'click');
            expect(button.className).not.toContain('medium-editor-button-active');
        });

        it('should execute the button action', function () {
            spyOn(MediumEditor.prototype, 'execAction');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            fireEvent(button, 'click');
            expect(editor.execAction).toHaveBeenCalled();
        });

        it('should call the execCommand for native actions', function () {
            spyOn(document, 'execCommand').andCallThrough();
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="i"]');
            fireEvent(button, 'click');
            expect(document.execCommand).toHaveBeenCalled();
            expect(this.el.innerHTML).toBe('<i>lorem ipsum</i>');
        });

        it('should execute the button action', function () {
            spyOn(MediumEditor.prototype, 'execAction');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="b"]');
            fireEvent(button, 'click');
            expect(editor.execAction).toHaveBeenCalled();
        });

        it('should call the triggerAnchorAction method when button element is "a"', function () {
            spyOn(MediumEditor.prototype, 'triggerAnchorAction');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="a"]');
            fireEvent(button, 'click');
            expect(editor.triggerAnchorAction).toHaveBeenCalled();
        });
    });

    describe('AppendEl', function () {
        beforeEach(function () {
            jasmine.Clock.useMock();
        });

        it('should call the execFormatBlock method when button action is append', function () {
            spyOn(MediumEditor.prototype, 'execFormatBlock');
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="h3"]');
            fireEvent(button, 'click');
            expect(editor.execFormatBlock).toHaveBeenCalled();
        });

        it('should create an h3 element when header1 is clicked', function () {
            this.el.innerHTML = '<p><b>lorem ipsum</b></p>';
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="h3"]');
            fireEvent(button, 'click');
            expect(this.el.innerHTML).toBe('<h3><b>lorem ipsum</b></h3>');
        });

        it('should get back to a p element if parent element is the same as the action', function () {
            this.el.innerHTML = '<h3><b>lorem ipsum</b></h3>';
            var button,
                editor = new MediumEditor('.editor');
            selectElementContents(editor.elements[0]);
            fireEvent(editor.elements[0], 'mouseup');
            jasmine.Clock.tick(1);
            button = editor.toolbar.querySelector('[data-element="h3"]');
            fireEvent(button, 'click');
            expect(this.el.innerHTML).toBe('<p><b>lorem ipsum</b></p>');
        });
    });

    describe('First and Last', function () {
        it('should add a special class to the first and last buttons', function () {
            var editor = new MediumEditor('.editor'),
                buttons = editor.toolbar.querySelectorAll('button');
            expect(buttons[0].className).toContain('medium-editor-button-first');
            expect(buttons[1].className).not.toContain('medium-editor-button-first');
            expect(buttons[1].className).not.toContain('medium-editor-button-last');
            expect(buttons[buttons.length - 1].className).toContain('medium-editor-button-last');
        });
    });
});
